<?php

# MiniFunx is a tiny series of very simple PHP functions, which shorten some existing PHP instructions to make them more user friendly.
# MiniFunx is being written and maintained by Daniele Lucchini (litterae.eu) since 2020.
# All rights reserved by the author. Yet you may use MiniFunx for free for non-commercial purposes only.


# CLI() -------------------------- replace <br> with \n if php is running in cli
function cli($string) {
    if (contains(php_sapi_name(),"cli") == true) { $string = str_replace("<br>","\n",$string); }
    return $string;
}
# echo cli("Break after this line.<br>");


# CONTAINS() --------------------------------- check if a string contains a word
function contains($string,$word) {
    if (strpos(strtolower($string),strtolower($word)) !== false) {
        return true;
    } else {
        return false;
    }
}
# if (contains("Alice in Wonderland","in") == true) { echo "ok"; } else { echo "no"; }
# NB: case insensitive check


# FCLOSE_MULTI() ------------------------------------ close more files at a time
function fclose_multi($files) {
    $files = func_get_args();
    foreach($files as $file) { fclose($file); }
}
# fclose_multi("one.csv","two.txt","three");


# DATE_ITALIAN() --------------------------- convert date to Italian full format
function date_italian($string) {
	$days = array("domenica","lunedì","martedì","mercoledì","giovedì","venerdì","sabato");
	$months = array("","gennaio","febbraio","marzo","aprile","maggio","giugno","luglio","agosto","settembre","ottobre","novembre","dicembre");
	$dn = date("w",strtotime($string)); $day_name = $days[$dn];
	$mn = (int)date("m",strtotime($string)); $month_name = $months[$mn];
	$day_number = date("j",strtotime($string)); $year = date("Y",strtotime($string));
	$string = "$day_name $day_number $month_name $year";
	return $string;
}
# date_italian("May 17 2023");


# DEACCENT() -------- remove and code accents in a string, e.g. for URL purposes
function deaccent($string) {
    # 1 grave accent, 2 acute accent, 3 circumflex accent, 4 diaeresis, | apostrophe, _ space
    $string = strtolower($string);
    $string = str_replace("à", "a1", $string);
    $string = str_replace("á", "a2", $string);
    $string = str_replace("â", "a3", $string);
    $string = str_replace("ä", "a4", $string);
    $string = str_replace("è", "e1", $string);
    $string = str_replace("é", "e2", $string);
    $string = str_replace("ê", "e3", $string);
    $string = str_replace("ë", "e4", $string);
    $string = str_replace("ì", "i1", $string);
    $string = str_replace("í", "i2", $string);
    $string = str_replace("î", "i3", $string);
    $string = str_replace("ï", "i4", $string);
    $string = str_replace("ò", "o1", $string);
    $string = str_replace("ó", "o2", $string);
    $string = str_replace("ô", "o3", $string);
    $string = str_replace("ö", "o4", $string);
    $string = str_replace("ù", "u1", $string);
    $string = str_replace("ú", "u2", $string);
    $string = str_replace("û", "u3", $string);
    $string = str_replace("ü", "u4", $string);
    $string = str_replace("ñ", "n3", $string);
    $string = str_replace("'", "|", $string);
    $string = str_replace(" ", "_", $string);
    return $string;
}
# $page = deaccent("C'è chi sì e c'è chi no.");


# DIACRITICS() ------------ remove diacritics in a string, e.g. for URL purposes
function diacritics($string) {
    $string = str_replace("À", "A", $string);
    $string = str_replace("Á", "A", $string);
    $string = str_replace("Â", "A", $string);
    $string = str_replace("Ã", "A", $string);
    $string = str_replace("Ä", "A", $string);
    $string = str_replace("Å", "A", $string);
    $string = str_replace("Æ", "AE", $string);
    $string = str_replace("Ç", "C", $string);
    $string = str_replace("È", "E", $string);
    $string = str_replace("É", "E", $string);
    $string = str_replace("Ê", "E", $string);
    $string = str_replace("Ë", "E", $string);
    $string = str_replace("Ì", "I", $string);
    $string = str_replace("Í", "I", $string);
    $string = str_replace("Î", "I", $string);
    $string = str_replace("Ï", "I", $string);
    $string = str_replace("Ð", "DH", $string);
    $string = str_replace("Ñ", "N", $string);
    $string = str_replace("Ò", "O", $string);
    $string = str_replace("Ó", "O", $string);
    $string = str_replace("Ô", "O", $string);
    $string = str_replace("Õ", "O", $string);
    $string = str_replace("Ö", "O", $string);
    $string = str_replace("Ø", "OE", $string);
    $string = str_replace("Ù", "U", $string);
    $string = str_replace("Ú", "U", $string);
    $string = str_replace("Û", "U", $string);
    $string = str_replace("Ü", "U", $string);
    $string = str_replace("Ý", "Y", $string);
    $string = str_replace("Þ", "TH", $string);
    $string = str_replace("ß", "ss", $string);
    $string = str_replace("à", "a", $string);
    $string = str_replace("á", "a", $string);
    $string = str_replace("â", "a", $string);
    $string = str_replace("ã", "a", $string);
    $string = str_replace("ä", "a", $string);
    $string = str_replace("å", "a", $string);
    $string = str_replace("æ", "ae", $string);
    $string = str_replace("ç", "c", $string);
    $string = str_replace("è", "e", $string);
    $string = str_replace("é", "e", $string);
    $string = str_replace("ê", "e", $string);
    $string = str_replace("ë", "e", $string);
    $string = str_replace("ì", "i", $string);
    $string = str_replace("í", "i", $string);
    $string = str_replace("î", "i", $string);
    $string = str_replace("ï", "i", $string);
    $string = str_replace("ð", "dh", $string);
    $string = str_replace("ñ", "n", $string);
    $string = str_replace("ò", "o", $string);
    $string = str_replace("ó", "o", $string);
    $string = str_replace("ô", "o", $string);
    $string = str_replace("õ", "o", $string);
    $string = str_replace("ö", "o", $string);
    $string = str_replace("ø", "oe", $string);
    $string = str_replace("ù", "u", $string);
    $string = str_replace("ú", "u", $string);
    $string = str_replace("û", "u", $string);
    $string = str_replace("ü", "u", $string);
    $string = str_replace("ý", "y", $string);
    $string = str_replace("þ", "th", $string);
    $string = str_replace("ÿ", "y", $string);
    $string = str_replace("Ā", "A", $string);
    $string = str_replace("ā", "a", $string);
    $string = str_replace("Ă", "A", $string);
    $string = str_replace("ă", "a", $string);
    $string = str_replace("Ą", "A", $string);
    $string = str_replace("ą", "a", $string);
    $string = str_replace("Ć", "C", $string);
    $string = str_replace("ć", "c", $string);
    $string = str_replace("Ĉ", "C", $string);
    $string = str_replace("ĉ", "c", $string);
    $string = str_replace("Ċ", "C", $string);
    $string = str_replace("ċ", "c", $string);
    $string = str_replace("Č", "C", $string);
    $string = str_replace("č", "c", $string);
    $string = str_replace("Ď", "D", $string);
    $string = str_replace("ď", "d", $string);
    $string = str_replace("Đ", "DH", $string);
    $string = str_replace("đ", "dh", $string);
    $string = str_replace("Ē", "E", $string);
    $string = str_replace("ē", "e", $string);
    $string = str_replace("Ĕ", "E", $string);
    $string = str_replace("ĕ", "e", $string);
    $string = str_replace("Ė", "E", $string);
    $string = str_replace("ė", "e", $string);
    $string = str_replace("Ę", "E", $string);
    $string = str_replace("ę", "e", $string);
    $string = str_replace("Ě", "E", $string);
    $string = str_replace("ě", "e", $string);
    $string = str_replace("Ĝ", "G", $string);
    $string = str_replace("ĝ", "g", $string);
    $string = str_replace("Ğ", "G", $string);
    $string = str_replace("ğ", "g", $string);
    $string = str_replace("Ġ", "G", $string);
    $string = str_replace("ġ", "g", $string);
    $string = str_replace("Ģ", "G", $string);
    $string = str_replace("ģ", "g", $string);
    $string = str_replace("Ĥ", "H", $string);
    $string = str_replace("ĥ", "h", $string);
    $string = str_replace("Ħ", "H", $string);
    $string = str_replace("ħ", "h", $string);
    $string = str_replace("Ĩ", "I", $string);
    $string = str_replace("ĩ", "i", $string);
    $string = str_replace("Ī", "I", $string);
    $string = str_replace("ī", "i", $string);
    $string = str_replace("Ĭ", "I", $string);
    $string = str_replace("ĭ", "i", $string);
    $string = str_replace("Į", "I", $string);
    $string = str_replace("į", "i", $string);
    $string = str_replace("İ", "I", $string);
    $string = str_replace("ı", "i", $string);
    $string = str_replace("Ĳ", "II", $string);
    $string = str_replace("ĳ", "ii", $string);
    $string = str_replace("Ĵ", "J", $string);
    $string = str_replace("ĵ", "j", $string);
    $string = str_replace("Ķ", "K", $string);
    $string = str_replace("ķ", "k", $string);
    $string = str_replace("ĸ", "k", $string);
    $string = str_replace("Ĺ", "L", $string);
    $string = str_replace("ĺ", "l", $string);
    $string = str_replace("Ļ", "L", $string);
    $string = str_replace("ļ", "l", $string);
    $string = str_replace("Ľ", "L", $string);
    $string = str_replace("ľ", "l", $string);
    $string = str_replace("Ŀ", "L", $string);
    $string = str_replace("ŀ", "l", $string);
    $string = str_replace("Ł", "L", $string);
    $string = str_replace("ł", "l", $string);
    $string = str_replace("Ń", "N", $string);
    $string = str_replace("ń", "n", $string);
    $string = str_replace("Ņ", "N", $string);
    $string = str_replace("ņ", "n", $string);
    $string = str_replace("Ň", "N", $string);
    $string = str_replace("ň", "n", $string);
    $string = str_replace("ŉ", "N", $string);
    $string = str_replace("Ŋ", "NG", $string);
    $string = str_replace("ŋ", "ng", $string);
    $string = str_replace("Ō", "O", $string);
    $string = str_replace("ō", "o", $string);
    $string = str_replace("Ŏ", "O", $string);
    $string = str_replace("ŏ", "o", $string);
    $string = str_replace("Ő", "O", $string);
    $string = str_replace("ő", "o", $string);
    $string = str_replace("Œ", "OE", $string);
    $string = str_replace("œ", "oe", $string);
    $string = str_replace("Ŕ", "R", $string);
    $string = str_replace("ŕ", "r", $string);
    $string = str_replace("Ŗ", "R", $string);
    $string = str_replace("ŗ", "r", $string);
    $string = str_replace("Ř", "R", $string);
    $string = str_replace("ř", "r", $string);
    $string = str_replace("Ś", "S", $string);
    $string = str_replace("ś", "s", $string);
    $string = str_replace("Ŝ", "S", $string);
    $string = str_replace("ŝ", "s", $string);
    $string = str_replace("Ş", "S", $string);
    $string = str_replace("ş", "s", $string);
    $string = str_replace("Š", "S", $string);
    $string = str_replace("š", "s", $string);
    $string = str_replace("Ţ", "T", $string);
    $string = str_replace("ţ", "t", $string);
    $string = str_replace("Ť", "T", $string);
    $string = str_replace("ť", "t", $string);
    $string = str_replace("Ŧ", "T", $string);
    $string = str_replace("ŧ", "t", $string);
    $string = str_replace("Ũ", "U", $string);
    $string = str_replace("ũ", "u", $string);
    $string = str_replace("Ū", "U", $string);
    $string = str_replace("ū", "u", $string);
    $string = str_replace("Ŭ", "U", $string);
    $string = str_replace("ŭ", "u", $string);
    $string = str_replace("Ů", "U", $string);
    $string = str_replace("ů", "u", $string);
    $string = str_replace("Ű", "U", $string);
    $string = str_replace("ű", "u", $string);
    $string = str_replace("Ų", "U", $string);
    $string = str_replace("ų", "u", $string);
    $string = str_replace("Ŵ", "W", $string);
    $string = str_replace("ŵ", "w", $string);
    $string = str_replace("Ŷ", "Y", $string);
    $string = str_replace("ŷ", "y", $string);
    $string = str_replace("Ÿ", "Y", $string);
    $string = str_replace("Ź", "Z", $string);
    $string = str_replace("ź", "z", $string);
    $string = str_replace("Ż", "Z", $string);
    $string = str_replace("ż", "z", $string);
    $string = str_replace("Ž", "Z", $string);
    $string = str_replace("ž", "z", $string);
    return $string;
}
# $page = diacritics("D'où la tempête est arrivée.");


# HAS_NUMBERS() ------------------------- check if a string contains any numbers
function has_numbers($string) {
    if (preg_match('~[0-9]+~', $string)) {
        return true;
    } else {
        return false;
    }
}
# es. if (has_numbers("Born in 1999.") == true) { echo "ok"; } else { echo "no"; }


# INCLUDE_MULTI() --------------------------------- include more files at a time
function include_multi($files) {
    $files = func_get_args();
    foreach($files as $file) { include_once($file); }
}
# es. include_multi("one.php","two.php","three.php");


# PULISCITITOLI -------------------------------- redundant variant of REACCENT()
function puliscititoli($stringa) {
    # 7 apostrofo - 1 accento grave - 2 accento acuto - 3 accento circonflesso
    $stringa = str_replace("--", "|", $stringa);
    $stringa = str_replace("-", " ", $stringa);
    $stringa = str_replace("|", " - ", $stringa);
    $stringa = str_replace("a1", "à", $stringa);
    $stringa = str_replace("a2", "á", $stringa);
    $stringa = str_replace("e1", "è", $stringa);
    $stringa = str_replace("e2", "é", $stringa);
    $stringa = str_replace("i1", "ì", $stringa);
    $stringa = str_replace("i2", "í", $stringa);
    $stringa = str_replace("o1", "ò", $stringa);
    $stringa = str_replace("o2", "ó", $stringa);
    $stringa = str_replace("u1", "ù", $stringa);
    $stringa = str_replace("u2", "ú", $stringa);
    $stringa = str_replace("n3", "ñ", $stringa);
    $stringa = str_replace("7", "'", $stringa);
    $stringa = ucwords($stringa);
    return $stringa;
}
# $titolo = puliscititoli("Torno li1, perche2 c7e1 gia1 buio.");


# RASNA ---------------------- convert Latin text to Old Italic RTL for Etruscan
function rasna($test) {
    $test = strtolower($test);
	// doppie e diacritiche
	$test = str_replace(array("th","θ"),array("𐌈","𐌈"),$test);
	$test = str_replace(array("sh","σ","ś","ŝ","ş","š","s1","s2"),array("𐌑","𐌑","𐌑","𐌑","𐌑","𐌑","𐌑","𐌑"),$test);
	$test = str_replace(array("ph","φ"),array("𐌘","𐌘"),$test);
	$test = str_replace(array("ch","kh","χ"),array("𐌙","𐌙","𐌙"),$test);
	$test = str_replace(array("è","é","ê","ë","ē","ĕ","ė","ě"),array("𐌭","𐌭","𐌭","𐌭","𐌭","𐌭","𐌭","𐌭"),$test);
	// semplici
	$test = str_replace("a","𐌀",$test);
	$test = str_replace("c","𐌂",$test);
	$test = str_replace("e","𐌄",$test);
	$test = str_replace("v","𐌅",$test);
	$test = str_replace("z","𐌆",$test);
	$test = str_replace("h","𐌇",$test);
	$test = str_replace("i","𐌉",$test);
	$test = str_replace("k","𐌊",$test);
	$test = str_replace("l","𐌋",$test);
	$test = str_replace("m","𐌌",$test);
	$test = str_replace("n","𐌍",$test);
	$test = str_replace("p","𐌐",$test);
	$test = str_replace("r","𐌓",$test);
	$test = str_replace("s","𐌔",$test);
	$test = str_replace("t","𐌕",$test);
	$test = str_replace("u","𐌖",$test);
	$test = str_replace("f","𐌚",$test);
	// arcaiche e sporadiche
	$test = str_replace("b","𐌁",$test);
	$test = str_replace("d","𐌃",$test);
	$test = str_replace("x","𐌎",$test);
	$test = str_replace("o","𐌏",$test);
	$test = str_replace("q","𐌒",$test);
	// scrivi da destra a sinistra
	$rtl = html_entity_decode("&#x202E;");
	$rtl_stop = html_entity_decode("&#x202C;");
	$test = $rtl.$test.$rtl_stop;
    return $test;
}
# echo rasna("mi larisal");


# REACCENT() ---------------------------- decode and rewrite accents in a string
function reaccent($string) {
    # 1 grave accent, 2 acute accent, 3 circumflex accent, 4 diaeresis, | apostrophe, _ space
    $string = str_replace("a1", "à", $string);
    $string = str_replace("a2", "á", $string);
    $string = str_replace("a3", "â", $string);
    $string = str_replace("a4", "ä", $string);
    $string = str_replace("e1", "è", $string);
    $string = str_replace("e2", "é", $string);
    $string = str_replace("e3", "ê", $string);
    $string = str_replace("e4", "ë", $string);
    $string = str_replace("i1", "ì", $string);
    $string = str_replace("i2", "í", $string);
    $string = str_replace("i3", "î", $string);
    $string = str_replace("i4", "ï", $string);
    $string = str_replace("o1", "ò", $string);
    $string = str_replace("o2", "ó", $string);
    $string = str_replace("o3", "ô", $string);
    $string = str_replace("o4", "ö", $string);
    $string = str_replace("u1", "ù", $string);
    $string = str_replace("u2", "ú", $string);
    $string = str_replace("u3", "û", $string);
    $string = str_replace("u4", "ü", $string);
    $string = str_replace("n3", "ñ", $string);
    $string = str_replace("|", "'", $string);
    $string = str_replace("_", " ", $string);
    $string = ucwords($string);
    return $string;
}
# $page = reaccent("C|e1_chi_si1_e_c|e1_chi_no.");


# REQUIRE_MULTI() --------------------------------- require more files at a time
function require_multi($files) {
    $files = func_get_args();
    foreach($files as $file) { require_once($file); }
}
# require_multi("one.php","two.php","three.php");


# SPACES() --------------------------------- delete redundant spaces in a string
function spaces($string) {
    $string = trim(preg_replace("/ {2,}/", " ", $string));
    return $string;
}
# echo spaces("  Once   upon a     time     ");


# TIMEZONE() ----------------------------------------------- set local time zone
function timezone($string) {
    date_default_timezone_set($string);
}
# timezone("Europe/Rome");


# URL_GET_CONTENTS() ------- alternative to file_get_contents() for remote files
function url_get_contents($Url) {
    if (!function_exists('curl_init')){
        die('CURL is not installed!');
    }
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $Url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $output = curl_exec($ch);
    curl_close($ch);
    return $output;
}
# $remotefile = url_get_contents("www.thatsite.com/page.html");

?>
